==> PyGeodesy-20.9.2.zip: PyGeodesy-20.9.2/pygeodesy/datum.py <==

# -*- coding: utf-8 -*-

u'''DEPRECATED, use module L{datums} or L{ellipsoids} instead.
'''
from pygeodesy.ellipsoids import *  # R_M, R_MA, R_MB, R_KM, R_NM, R_SM, R_FM, R_VM, \
from pygeodesy.ellipsoids import Curvature2Tuple  # Ellipsoid, Ellipsoids  # PYCHOK exported
from pygeodesy.datums import *  # Datum, Datums, Transform, Transforms  # PYCHOK exported
from pygeodesy.lazily import _ALL_DOCS, _ALL_LAZY

__all__ = _ALL_LAZY.datums + _ALL_LAZY.ellipsoids + _ALL_DOCS(Curvature2Tuple)
__version__ = '20.08.25'

# **) MIT License
#
# Copyright (C) 2016-2020 -- mrJean1 at Gmail -- All Rights Reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

==> PyGeodesy-20.10.6.zip: PyGeodesy-20.10.6/pygeodesy/datum.py <==

# -*- coding: utf-8 -*-

u'''DEPRECATED, use module L{datums} or L{ellipsoids} instead.
'''
# XXX only the items previously public
from pygeodesy.ellipsoids import R_M, R_MA, R_MB, R_KM, R_NM, R_SM, R_FM, R_VM, \
                                 Ellipsoid, Ellipsoids, Curvature2Tuple  # PYCHOK exported
from pygeodesy.datums import Datum, Datums, Transform, Transforms  # PYCHOK exported

__all__ = ('R_M', 'R_MA', 'R_MB', 'R_KM', 'R_NM', 'R_SM', 'R_FM', 'R_VM',
            Datum.__name__, Ellipsoid.__name__, Transform.__name__, Curvature2Tuple.__name__,
           'Datums',       'Ellipsoids',       'Transforms')
__version__ = '20.09.27'

# **) MIT License
#
# Copyright (C) 2016-2020 -- mrJean1 at Gmail -- All Rights Reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
